package org.processmining.performancespectrum.plugins;

import javax.swing.JComponent;
import javax.swing.JPanel;

import org.deckfour.xes.model.XLog;
import org.processmining.contexts.uitopia.UIPluginContext;
import org.processmining.contexts.uitopia.annotations.UITopiaVariant;
import org.processmining.contexts.uitopia.annotations.Visualizer;
import org.processmining.framework.plugin.annotations.Plugin;
import org.processmining.framework.plugin.annotations.PluginVariant;
import org.processmining.performancespectrum.algorithms.YourAlgorithm;
import org.processmining.scala.viewers.spectrum.view.FramePanel;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class PsmPlugin extends YourAlgorithm {

	private static final Logger logger = LoggerFactory.getLogger(PsmPlugin.class.getName());
	
	public PsmPlugin() {
		if(!FramePanel.checkJvm()){
			throw new IllegalStateException("Wrong JVM version");
		}
		FramePanel.reportToLog("Performance Spectrum Miner created");
	}

	/**
	 * The plug-in variant that runs in any context and requires a parameters.
	 * 
	 * @param context
	 *            The context to run in.
	 * @param psm
	 *            the PSM panel
	 * @return a panel to show calculated capacities.
	 */
	@Plugin(name = "Performance Spectrum Vizualizer", parameterLabels = { "Performance Spectrum" }, returnLabels = {
			"Performance Spectrum" }, returnTypes = { JComponent.class }, help = "", userAccessible = true)
	@Visualizer
	public JPanel runUI(final UIPluginContext context, final FramePanel psm) {
		return psm;
	}

	@UITopiaVariant(affiliation = UITopiaVariant.EHV, author = "Vadim Denisov, Elena Belkina, Dirk Fahland, Wil van der Aalst", email = "v.denisov@tue.nl")
	@PluginVariant(variantLabel = "Event log", requiredParameterLabels = { 0 })
	@Plugin(name = "Performance Spectrum Miner", parameterLabels = { "Event Log" }, returnLabels = {
			"Performance Spectrum" }, returnTypes = { FramePanel.class }, help = "", userAccessible = true)
	public FramePanel runUI(final UIPluginContext context, final XLog xlog) {
		
		return new FramePanel(xlog);
	}

	@UITopiaVariant(affiliation = UITopiaVariant.EHV, author = "Vadim Denisov, Elena Belkina, Dirk Fahland, Wil van der Aalst", email = "v.denisov@tue.nl")
	@PluginVariant(variantLabel = "Performance Spectrum", requiredParameterLabels = { 0 })
	@Plugin(name = "Performance Spectrum Miner Viewer", parameterLabels = { "Performance Spectrum" }, returnLabels = {
			"Performance Spectrum" }, returnTypes = { FramePanel.class }, help = "", userAccessible = true)
	public FramePanel runUI(final UIPluginContext context, final PerformanceSpectrumDirectory container) {
		return new FramePanel(container.dir, null, false, true);
	}

	@UITopiaVariant(affiliation = UITopiaVariant.EHV, author = "Vadim Denisov, Elena Belkina, Dirk Fahland, Wil van der Aalst", email = "v.denisov@tue.nl")
	@PluginVariant(variantLabel = "Directory of event logs in CSV format", requiredParameterLabels = { 0 })
	@Plugin(name = "Performance Spectrum Miner (multiple event logs)", parameterLabels = { "Event logs" }, returnLabels = {
			"Performance Spectrum" }, returnTypes = { FramePanel.class }, help = "", userAccessible = true)
	public FramePanel runUI(final UIPluginContext context, final PerformanceSpectrumCsvDirectory container) {
		return new FramePanel(container.dir);
	}

	@UITopiaVariant(affiliation = UITopiaVariant.EHV, author = "Vadim Denisov, Elena Belkina, Dirk Fahland, Wil van der Aalst", email = "v.denisov@tue.nl")
	@PluginVariant(variantLabel = "Directory of segment files", requiredParameterLabels = { 0 })
	@Plugin(name = "Performance Spectrum Miner (segment files)", parameterLabels = { "Segment files" }, returnLabels = {
			"Performance Spectrum" }, returnTypes = { FramePanel.class }, help = "", userAccessible = true)
	public FramePanel runUI(final UIPluginContext context, final PerformanceSpectrumSegDirectory container) {
		return new FramePanel(container.dir);
	}

}
